@@ -12,6 +12,16 @@ from .vars import COGNITO_NETLOC_MAPPING, CREDSTORE_PATH, DEFAULT_PROFILE
 _logger = logging.getLogger(__name__)
 
 
+def get_profiles():
+    if CREDSTORE_PATH.exists() and CREDSTORE_PATH.is_file():
+        with CREDSTORE_PATH.open() as f:
+            return json.load(f)
+    else:
+        raise Exception(
+            "No NND credentials found, please use `nnd login` or set environment variables"
+        )
+
+
 def login(username, password, userpool_id, client_id):
     user = Cognito(
         userpool_id,
@@ -38,13 +48,8 @@ class NNDAuth(AuthBase):
         self.overrides = {}
         if environ.get("NND_USERNAME") and environ.get("NND_PASSWORD"):
             _logger.info("Found environment variables will use those instead")
-        elif CREDSTORE_PATH.exists() and CREDSTORE_PATH.is_file():
-            with CREDSTORE_PATH.open() as f:
-                self.creds = json.load(f)
         else:
-            raise Exception(
-                "No NND credentials found, please use `nnd login` or set environment variables"
-            )
+            self.creds = get_profiles()
 
     def __call__(self, request):
         netloc = urlparse(request.url).netloc
