@@ -6,7 +6,6 @@ import click
 import requests
 from pycognito import Cognito
 
-from .auth import NNDAuth
 from .vars import COGNITO_NETLOC_MAPPING, CREDSTORE_PATH, DEFAULT_PROFILE
 
 
@@ -66,11 +65,11 @@ def login(profile, nomitall_url, username, password):
     try:
         user.authenticate(password=password)
     except user.client.exceptions.UserNotFoundException:
-        raise click.ClickException(f"Nom Nom Data username not found {username}")
+        raise click.Abort(f"Nom Nom Data username not found {username}")
     except user.client.exceptions.NotAuthorizedException:
-        raise click.ClickException(f"Authorization failed {username}")
+        raise click.Abort(f"Authorization failed {username}")
     except user.client.exceptions.PasswordResetRequiredException:
-        raise click.ClickException(f"Password reset required for {username}")
+        raise click.Abort(f"Password reset required for {username}")
     creds[profile][base_url] = {
         "access-token": user.access_token,
         "refresh-token": user.refresh_token,
